@@ -294,19 +294,15 @@
 // Digest manager routines
 //
 
-//#include <windows.h>
-
 #include <pthread.h>
-  #include <string.h>            // for memcmp() et al
-  #include <stdlib.h>
-
+#include <string.h>            // for memcmp() et al
+#include <stdlib.h>
 
 #include "pkcs11types.h"
 #include "defs.h"
 #include "host_defs.h"
 #include "h_extern.h"
 #include "tok_spec_struct.h"
-//#include "args.h"
 
 
 //
@@ -318,7 +314,6 @@ digest_mgr_init( SESSION           *sess,
 {
    CK_BYTE  * ptr = NULL;
 
-
    if (!sess || !ctx){
       st_err_log(4, __FILE__, __LINE__, __FUNCTION__);
       return CKR_FUNCTION_FAILED;
@@ -327,7 +322,6 @@ digest_mgr_init( SESSION           *sess,
       st_err_log(31, __FILE__, __LINE__);     
       return CKR_OPERATION_ACTIVE;
    }
-
    // is the mechanism supported?  is the parameter present if required?
    //
    switch (mech->mechanism) {
@@ -348,6 +342,57 @@ digest_mgr_init( SESSION           *sess,
          }
          break;
 
+      case CKM_SHA256:
+         {
+            if (mech->ulParameterLen != 0){
+               st_err_log(29, __FILE__, __LINE__);
+               return CKR_MECHANISM_PARAM_INVALID;
+            }
+
+            ctx->context = NULL;
+            ckm_sha2_init( ctx );
+
+            if (!ctx->context) {
+               st_err_log(1, __FILE__, __LINE__);
+               return CKR_HOST_MEMORY;
+            }
+         }
+         break;
+
+      case CKM_SHA384:
+         {
+            if (mech->ulParameterLen != 0){
+               st_err_log(29, __FILE__, __LINE__);
+               return CKR_MECHANISM_PARAM_INVALID;
+            }
+
+            ctx->context = NULL;
+            ckm_sha3_init( ctx );
+
+            if (!ctx->context) {
+               st_err_log(1, __FILE__, __LINE__);
+               return CKR_HOST_MEMORY;
+            }
+         }
+         break;
+
+      case CKM_SHA512:
+         {
+            if (mech->ulParameterLen != 0){
+               st_err_log(29, __FILE__, __LINE__);
+               return CKR_MECHANISM_PARAM_INVALID;
+            }
+
+            ctx->context = NULL;
+            ckm_sha5_init( ctx );
+
+            if (!ctx->context) {
+               st_err_log(1, __FILE__, __LINE__);
+               return CKR_HOST_MEMORY;
+            }
+         }
+         break;
+
       case CKM_MD2:
          {
             if (mech->ulParameterLen != 0){
@@ -385,7 +430,6 @@ digest_mgr_init( SESSION           *sess,
          return CKR_MECHANISM_INVALID;
    }
 
-
    if (mech->ulParameterLen > 0) {
       ptr = (CK_BYTE *)malloc(mech->ulParameterLen);
       if (!ptr){
@@ -394,7 +438,6 @@ digest_mgr_init( SESSION           *sess,
       }
       memcpy( ptr, mech->pParameter, mech->ulParameterLen );
    }
-
    ctx->mech.ulParameterLen = mech->ulParameterLen;
    ctx->mech.mechanism      = mech->mechanism;
    ctx->mech.pParameter     = ptr;
@@ -474,6 +517,21 @@ digest_mgr_digest( SESSION         *sess,
                            in_data,   in_data_len,
                            out_data,  out_data_len );
 
+      case CKM_SHA256:
+         return sha2_hash( sess,      length_only, ctx,
+                           in_data,   in_data_len,
+                           out_data,  out_data_len );
+
+      case CKM_SHA384:
+         return sha3_hash( sess,      length_only, ctx,
+                           in_data,   in_data_len,
+                           out_data,  out_data_len );
+
+      case CKM_SHA512:
+         return sha5_hash( sess,      length_only, ctx,
+                           in_data,   in_data_len,
+                           out_data,  out_data_len );
+
 #if !(NOMD2 )
       case CKM_MD2:
          return md2_hash( sess,     length_only, ctx,
@@ -519,6 +577,15 @@ digest_mgr_digest_update( SESSION         *sess,
       case CKM_SHA_1:
          return sha1_hash_update( sess, ctx, data, data_len );
 
+      case CKM_SHA256:
+         return sha2_hash_update( sess, ctx, data, data_len );
+
+      case CKM_SHA384:
+         return sha3_hash_update( sess, ctx, data, data_len );
+
+      case CKM_SHA512:
+         return sha5_hash_update( sess, ctx, data, data_len );
+
 #if !(NOMD2)
       case CKM_MD2:
          return md2_hash_update( sess, ctx, data, data_len );
@@ -622,6 +689,21 @@ digest_mgr_digest_final( SESSION         *sess,
                                  ctx,
                                  hash, hash_len );
 
+      case CKM_SHA256:
+         return sha2_hash_final( sess, length_only,
+                                 ctx,
+                                 hash, hash_len );
+
+      case CKM_SHA384:
+         return sha3_hash_final( sess, length_only,
+                                 ctx,
+                                 hash, hash_len );
+
+      case CKM_SHA512:
+         return sha5_hash_final( sess, length_only,
+                                 ctx,
+                                 hash, hash_len );
+
 #if !(NOMD2)
       case CKM_MD2:
          return md2_hash_final( sess, length_only,
