@@ -303,19 +303,16 @@
 // File:  key_mgr.c
 //
 
-//#include <windows.h>
-
 #include <pthread.h>
 #include <stdlib.h>
 
- #include <string.h>  // for memcmp() et al
+#include <string.h>  // for memcmp() et al
 
 #include "pkcs11types.h"
 #include "defs.h"
 #include "host_defs.h"
 #include "h_extern.h"
 #include "tok_spec_struct.h"
-//#include "args.h"
 
 
 static CK_BBOOL true = TRUE, false = FALSE;
@@ -755,6 +752,10 @@ key_mgr_generate_key_pair( SESSION           * sess,
    rc = object_mgr_create_final( sess, priv_key_obj, priv_key_handle );
    if (rc != CKR_OK){
       st_err_log(90, __FILE__, __LINE__);
+      // just calling object_free in the error path below would lead to a double
+      // free error on session close - KEY 09/26/07
+      object_mgr_destroy_object( sess, *publ_key_handle );
+      publ_key_obj = NULL;
       goto error;
    }
    return rc;
