@@ -474,12 +474,14 @@ save_token_data()
 
    //sprintf((char *)fname,"%s/%s",pk_dir, PK_LITE_NV);
    //fp = fopen("/tmp/NVTOK.DAT", "w");
-   fp = fopen((char *)fname, "w");
-
+   fp = fopen((char *)fname, "r+");
    if (!fp){
-      st_err_log(4, __FILE__, __LINE__, __FUNCTION__);
-      rc = CKR_FUNCTION_FAILED;
-      goto done;
+      fp = fopen((char *)fname, "w");
+      if (!fp) {
+         st_err_log(4, __FILE__, __LINE__, __FUNCTION__);
+         rc = CKR_FUNCTION_FAILED;
+         goto done;
+      }
    }
    set_perm(fileno(fp));
 
